pub struct History { /* private fields */ }Expand description
Contains history of past pairings
Implementations
Sourceimpl History
impl History
Sourcepub fn from_dir(dir: &str) -> Result<Self, BuddyError>
pub fn from_dir(dir: &str) -> Result<Self, BuddyError>
Usually the history is saved in some directory. Give it a directory name to read that history. If you’re just starting out, give it the desired directory. If it doesn’t exist, it will be created.
pub fn stats(&self) -> HistoryStats
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn get(&self, pair: (usize, usize)) -> Option<usize>
pub fn min(&self) -> usize
pub fn max(&self) -> usize