pub struct People { /* private fields */ }Expand description
Implementations
Sourceimpl People
impl People
Sourcepub fn from_csv<R: Read>(input: R) -> Result<Self, BuddyError>
pub fn from_csv<R: Read>(input: R) -> Result<Self, BuddyError>
Reads people from a CSV file and creates a People struct from that.
The expected format is rows of people like id,name.
Example CSV:
1,John
2,DavidIf the given input doesn’t contain an even number of people, we will add our own with id
usize::MAX, so that id is reserved.
Having that extra user to make it even will keep the algorithm working, so that someone
will be “paired up” with our evenizer, which really means that person won’t get paired.
The beautiful thing is that the algorithm will try and not repeat pairs, which now includes
the evenizer, so the same person will not end up getting not paired all the time.
pub fn len(&self) -> usize
Sourcepub fn has_evenizer(&self) -> bool
pub fn has_evenizer(&self) -> bool
Whether this People set has our evenizer user to make the count even.
pub fn is_empty(&self) -> bool